==> freecad_0.10.3247.dfsg.orig.tar.gz: FreeCAD-0.10.3247/src/Mod/Points/Gui/Resources/translations/Points_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>CmdPointsExport</name>
    <message>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <source>Export points...</source>
        <translation>Exporter les points...</translation>
    </message>
    <message>
        <source>Exports a point cloud</source>
        <translation>Exporte un nuage de point</translation>
    </message>
</context>
<context>
    <name>CmdPointsImport</name>
    <message>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <source>Import points...</source>
        <translation>Importer des points...</translation>
    </message>
    <message>
        <source>Imports a point cloud</source>
        <translation>Importe un nuage de points</translation>
    </message>
</context>
<context>
    <name>CmdPointsPolyCut</name>
    <message>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <source>Cut point cloud</source>
        <translation>Couper un nuage de points</translation>
    </message>
    <message>
        <source>Cuts a point cloud with a picked polygon</source>
        <translation>Coupe un nuage de points à l&apos;aide d&apos;un polygone sélectionné</translation>
    </message>
</context>
<context>
    <name>CmdPointsTransform</name>
    <message>
        <source>Points</source>
        <translation type="unfinished">Points</translation>
    </message>
    <message>
        <source>Transform Points</source>
        <translation type="unfinished">Transformer les points</translation>
    </message>
    <message>
        <source>Test to transform a point cloud</source>
        <translation type="unfinished">Test de transformation d&apos;un nuage de points</translation>
    </message>
</context>
<context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
        <source>ASCII points import</source>
        <translation>Import de points ASCII</translation>
    </message>
    <message>
        <source>Template:</source>
        <translation>Modèle:</translation>
    </message>
    <message>
        <source>Special lines</source>
        <translation>Ligne spéciales</translation>
    </message>
    <message>
        <source>First line:</source>
        <translation>Première ligne:</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Cluster by lines starting with:</source>
        <translation>Ensemble de lignes commençant par:</translation>
    </message>
    <message>
        <source>Ignore lines starting with:</source>
        <translation>Ignorer les lignes commençant par:</translation>
    </message>
    <message>
        <source>Point format</source>
        <translation>Format de point</translation>
    </message>
    <message>
        <source>Number seperator:</source>
        <translation>Séparateur de nombres:</translation>
    </message>
    <message>
        <source>Points format:</source>
        <translation>Format de points:</translation>
    </message>
    <message>
        <source>Next block:</source>
        <translation>Bloc suivant:</translation>
    </message>
    <message>
        <source>,</source>
        <translation>,</translation>
    </message>
    <message>
        <source>;</source>
        <translation>;</translation>
    </message>
    <message>
        <source>\t</source>
        <translation>\t</translation>
    </message>
    <message>
        <source>\w</source>
        <translation>\w</translation>
    </message>
    <message>
        <source>X,Y,Z</source>
        <translation>X,Y,Z</translation>
    </message>
    <message>
        <source>X,Y</source>
        <translation>X,Y</translation>
    </message>
    <message>
        <source>none</source>
        <translation>aucun</translation>
    </message>
    <message>
        <source>I,J,K (normal vector)</source>
        <translation>I,J,K (vecteur normal)</translation>
    </message>
    <message>
        <source>I,K (normal vector 2D)</source>
        <translation>I,K (vecteur normal 2D)</translation>
    </message>
    <message>
        <source>R,G,B (color)</source>
        <translation>R,V,B (couleur)</translation>
    </message>
    <message>
        <source>I (Gray value)</source>
        <translation>I (valeur de gris)</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <source>Number of points</source>
        <translation>Nombre de points</translation>
    </message>
    <message>
        <source>Number of previewd lines:</source>
        <translation>Nombre de lignes prévisualisées:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Ascii Points (*.asc);;All Files (*.*)</source>
        <translation type="unfinished">Points Ascii (*.asc);;Tous les fichiers (*.*)</translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <source>Points tools</source>
        <translation>Outils points</translation>
    </message>
    <message>
        <source>&amp;Points</source>
        <translation>&amp;Points</translation>
    </message>
</context>
</TS>

==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Points/Gui/Resources/translations/Points_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CmdPointsExport</name>
    <message>
        <location filename="../../Command.cpp" line="+104"/>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Export points...</source>
        <translation>Exporter les points...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Exports a point cloud</source>
        <translation>Exporte un nuage de point</translation>
    </message>
</context>
<context>
    <name>CmdPointsImport</name>
    <message>
        <location line="-47"/>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Import points...</source>
        <translation>Importer des points...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Imports a point cloud</source>
        <translation>Importe un nuage de points</translation>
    </message>
</context>
<context>
    <name>CmdPointsPolyCut</name>
    <message>
        <location line="+122"/>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cut point cloud</source>
        <translation>Couper un nuage de points</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cuts a point cloud with a picked polygon</source>
        <translation>Coupe un nuage de points à l&apos;aide d&apos;un polygone sélectionné</translation>
    </message>
</context>
<context>
    <name>CmdPointsTransform</name>
    <message>
        <location line="-39"/>
        <source>Points</source>
        <translation>Points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Transform Points</source>
        <translation>Transformer les points</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Test to transform a point cloud</source>
        <translation>Test de transformation d&apos;un nuage de points</translation>
    </message>
</context>
<context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
        <location filename="../../DlgPointsRead.ui" line="+14"/>
        <source>ASCII points import</source>
        <translation>Import de points ASCII</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Template:</source>
        <translation>Modèle:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Special lines</source>
        <translation>Ligne spéciales</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>First line:</source>
        <translation>Première ligne:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <location line="-21"/>
        <source>Cluster by lines starting with:</source>
        <translation>Ensemble de lignes commençant par:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ignore lines starting with:</source>
        <translation>Ignorer les lignes commençant par:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Point format</source>
        <translation>Format de point</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number separator:</source>
        <translation>Séparateur de nombres:</translation>
    </message>
    <message>
        <location line="+98"/>
        <source>Points format:</source>
        <translation>Format de points:</translation>
    </message>
    <message>
        <location line="-91"/>
        <location line="+7"/>
        <location line="+7"/>
        <source>Next block:</source>
        <translation>Bloc suivant:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>,</source>
        <translation>,</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>;</source>
        <translation>;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>\t</source>
        <translation>\t</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>\w</source>
        <translation>\w</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>X,Y,Z</source>
        <translation>X, Y, Z</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>X,Y</source>
        <translation>X, Y</translation>
    </message>
    <message>
        <location line="-147"/>
        <location line="+29"/>
        <location line="+57"/>
        <source>none</source>
        <translation>aucun</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+29"/>
        <location line="+57"/>
        <source>I,J,K (normal vector)</source>
        <translation>I,J,K (vecteur normal)</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+29"/>
        <location line="+57"/>
        <source>I,K (normal vector 2D)</source>
        <translation>I,K (vecteur normal 2D)</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+29"/>
        <location line="+57"/>
        <source>R,G,B (color)</source>
        <translation>R,V,B (couleur)</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+29"/>
        <location line="+57"/>
        <source>I (Gray value)</source>
        <translation>I (valeur de gris)</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Number of points</source>
        <translation>Nombre de points</translation>
    </message>
    <message>
        <location line="+231"/>
        <source>Number of previewed lines:</source>
        <translation>Nombre de lignes prévisualisés :</translation>
    </message>
</context>
<context>
    <name>PointsGui::Workbench</name>
    <message>
        <source>Points tools</source>
        <translation type="obsolete">Outils points</translation>
    </message>
    <message>
        <source>&amp;Points</source>
        <translation type="obsolete">&amp;Points</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Command.cpp" line="-84"/>
        <location line="+43"/>
        <source>Ascii Points (*.asc);;All Files (*.*)</source>
        <translation>Points Ascii (*.asc);;Tous les fichiers (*.*)</translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="+37"/>
        <source>Points tools</source>
        <translation>Outils points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Points</source>
        <translation>&amp;Points</translation>
    </message>
</context>
</TS>
